@@ -63,12 +63,16 @@ class socket_address_inet6;
 class socket_address {
 public:
   static const sa_family_t af_local  = AF_LOCAL;
-  static const sa_family_t af_unix   = AF_UNIX;
-  //  static const sa_family_t af_file   = AF_FILE;
   static const sa_family_t af_inet   = AF_INET;
   static const sa_family_t af_inet6  = AF_INET6;
   static const sa_family_t af_unspec = AF_UNSPEC;
 
+#ifdef AF_UNIX
+  static const sa_family_t af_unix   = AF_UNIX;
+#else
+  static const sa_family_t af_unix   = AF_FILE;
+#endif
+
   bool                is_valid() const;
   bool                is_bindable() const;
   bool                is_address_any() const;
