@@ -47,7 +47,7 @@ bool
 HashChunk::perform(uint32_t length, bool force) {
   length = std::min(length, remaining());
 
-  if (m_position + length > m_chunk.chunk()->size())
+  if (m_position + length > m_chunk.chunk()->chunk_size())
     throw internal_error("HashChunk::perform(...) received length out of range");
   
   uint32_t l = force ? length : m_chunk.chunk()->incore_length(m_position);
@@ -68,7 +68,7 @@ HashChunk::advise_willneed(uint32_t length) {
   if (!m_chunk.is_valid())
     throw internal_error("HashChunk::willneed(...) called on an invalid chunk");
 
-  if (m_position + length > m_chunk.chunk()->size())
+  if (m_position + length > m_chunk.chunk()->chunk_size())
     throw internal_error("HashChunk::willneed(...) received length out of range");
 
   uint32_t pos = m_position;
@@ -91,7 +91,7 @@ HashChunk::remaining() {
   if (!m_chunk.is_valid())
     throw internal_error("HashChunk::remaining(...) called on an invalid chunk");
 
-  return m_chunk.chunk()->size() - m_position;
+  return m_chunk.chunk()->chunk_size() - m_position;
 }
 
 uint32_t
