@@ -37,14 +37,12 @@
 #ifndef LIBTORRENT_DATA_HASH_QUEUE_H
 #define LIBTORRENT_DATA_HASH_QUEUE_H
 
-#include <string>
-#include <list>
+#include <deque>
+#include <rak/priority_queue_default.h>
 
 #include "hash_queue_node.h"
 #include "chunk_handle.h"
 
-#include "globals.h"
-
 namespace torrent {
 
 class HashChunk;
@@ -55,10 +53,10 @@ class HashChunk;
 // helps us in getting as much done as possible while the pages are in
 // memory.
 
-class HashQueue : private std::list<HashQueueNode> {
+class HashQueue : private std::deque<HashQueueNode> {
 public:
-  typedef std::list<HashQueueNode> base_type;
-  typedef HashQueueNode::SlotDone  SlotDone;
+  typedef std::deque<HashQueueNode>     base_type;
+  typedef HashQueueNode::slot_done_type slot_done_type;
 
   using base_type::iterator;
 
@@ -70,7 +68,7 @@ public:
   HashQueue();
   ~HashQueue() { clear(); }
 
-  void                push_back(ChunkHandle handle, SlotDone d);
+  void                push_back(ChunkHandle handle, slot_done_type d);
 
   bool                has(HashQueueNode::id_type id);
   bool                has(HashQueueNode::id_type id, uint32_t index);
