@@ -45,46 +45,61 @@
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
+#include <rak/socket_address.h>
 
 #include "torrent/exceptions.h"
-#include "socket_address.h"
 #include "socket_fd.h"
 
 namespace torrent {
 
+inline void
+SocketFd::check_valid() const {
+  if (!is_valid())
+    throw internal_error("SocketFd function called on an invalid fd.");
+}
+
 bool
 SocketFd::set_nonblock() {
-  if (!is_valid())
-    throw internal_error("SocketFd::set_nonblock() called on a closed fd.");
+  check_valid();
 
   return fcntl(m_fd, F_SETFL, O_NONBLOCK) == 0;
 }
 
 bool
-SocketFd::set_throughput() {
-  if (!is_valid())
-    throw internal_error("SocketFd::set_throughput() called on a closed fd.");
-
-  int opt = IPTOS_THROUGHPUT;
+SocketFd::set_priority(priority_type p) {
+  check_valid();
+  int opt = p;
 
   return setsockopt(m_fd, IPPROTO_IP, IP_TOS, &opt, sizeof(opt)) == 0;
 }
 
 bool
 SocketFd::set_reuse_address(bool state) {
-  if (!is_valid())
-    throw internal_error("SocketFd::set_reuse_address(bool) called on a closed fd.");
-
+  check_valid();
   int opt = state;
 
   return setsockopt(m_fd, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(opt)) == 0;
 }
 
+bool
+SocketFd::set_send_buffer_size(uint32_t s) {
+  check_valid();
+  int opt = s;
+
+  return setsockopt(m_fd, SOL_SOCKET, SO_SNDBUF, &opt, sizeof(opt)) == 0;
+}
+
+bool
+SocketFd::set_receive_buffer_size(uint32_t s) {
+  check_valid();
+  int opt = s;
+
+  return setsockopt(m_fd, SOL_SOCKET, SO_RCVBUF, &opt, sizeof(opt)) == 0;
+}
 
 int
 SocketFd::get_error() const {
-  if (!is_valid())
-    throw internal_error("SocketFd::get_error() called on a closed fd");
+  check_valid();
 
   int err;
   socklen_t length = sizeof(err);
@@ -112,37 +127,32 @@ SocketFd::close() {
 }
 
 bool
-SocketFd::bind(const SocketAddress& sa) {
-  if (!is_valid())
-    throw internal_error("SocketFd::bind(...) called on a closed fd");
+SocketFd::bind(const rak::socket_address& sa) {
+  check_valid();
 
-  return !::bind(m_fd, &sa.get_addr(), sa.get_sizeof());
+  return !::bind(m_fd, sa.c_sockaddr(), sa.length());
 }
 
 bool
-SocketFd::connect(const SocketAddress& sa) {
-  if (!is_valid())
-    throw internal_error("SocketFd::connect(...) called on a closed fd");
+SocketFd::connect(const rak::socket_address& sa) {
+  check_valid();
 
-  return !::connect(m_fd, &sa.get_addr(), sa.get_sizeof()) || errno == EINPROGRESS;
+  return !::connect(m_fd, sa.c_sockaddr(), sa.length()) || errno == EINPROGRESS;
 }
 
 bool
 SocketFd::listen(int size) {
-  if (!is_valid())
-    throw internal_error("SocketFd::listen(...) called on a closed fd");
+  check_valid();
 
   return !::listen(m_fd, size);
 }
 
 SocketFd
-SocketFd::accept(SocketAddress* sa) {
-  if (!is_valid())
-    throw internal_error("SocketFd::accept(...) called on a closed fd");
+SocketFd::accept(rak::socket_address* sa) {
+  check_valid();
+  socklen_t len = sizeof(rak::socket_address);
 
-  socklen_t len = sa->get_sizeof();
-
-  return SocketFd(::accept(m_fd, sa != NULL ? &sa->get_addr() : NULL, &len));
+  return SocketFd(::accept(m_fd, sa != NULL ? sa->c_sockaddr() : NULL, &len));
 }
 
 // unsigned int
