@@ -42,6 +42,7 @@
 #include <rak/functional.h>
 #include <rak/unordered_vector.h>
 #include <rak/socket_address.h>
+#include <torrent/connection_manager.h>
 
 #include "net/socket_fd.h"
 
@@ -57,7 +58,7 @@ public:
   typedef rak::unordered_vector<Handshake*> base_type;
   typedef uint32_t                          size_type;
 
-  typedef rak::mem_fun1<DownloadManager, DownloadMain*, const std::string&> SlotDownloadId;
+  typedef rak::mem_fun1<DownloadManager, DownloadMain*, const char*> SlotDownloadId;
 
   using base_type::empty;
 
@@ -77,24 +78,25 @@ public:
   void                add_incoming(SocketFd fd, const rak::socket_address& sa);
   void                add_outgoing(const rak::socket_address& sa, DownloadMain* info);
 
-  void                slot_download_id(SlotDownloadId s)        { m_slotDownloadId = s; }
+  void                slot_download_id(SlotDownloadId s)                { m_slotDownloadId = s; }
+  void                slot_download_id_obfuscated(SlotDownloadId s)     { m_slotDownloadIdObfuscated = s; }
 
   void                receive_succeeded(Handshake* h);
-  void                receive_failed(Handshake* h);
+  void                receive_failed(Handshake* h, int message, int error);
+  void                receive_timeout(Handshake* h);
 
   // This needs to be filterable slot.
-  DownloadMain*       download_info(const std::string& hash)    { return m_slotDownloadId(hash); }
+  DownloadMain*       download_info(const char* hash)                   { return m_slotDownloadId(hash); }
+  DownloadMain*       download_info_obfuscated(const char* hash)        { return m_slotDownloadIdObfuscated(hash); }
 
 private:
+  void                create_outgoing(const rak::socket_address& sa, DownloadMain* info, int encryptionOptions);
   void                erase(Handshake* handshake);
 
   bool                setup_socket(SocketFd fd);
 
-  inline void         delete_handshake(Handshake* h);
-
-  inline void         post_insert(Handshake* h, PeerConnectionBase* pcb);
-
   SlotDownloadId      m_slotDownloadId;
+  SlotDownloadId      m_slotDownloadIdObfuscated;
 };
 
 }
