@@ -119,7 +119,7 @@ Download::stop() {
 bool
 Download::hash_check(bool tryQuick) {
   if (m_ptr->hash_checker()->is_checking())
-    return m_ptr->hash_checker()->start(tryQuick);
+    throw internal_error("Download::hash_check(...) called but the hash is already being checked.");
 
   if (!m_ptr->info()->is_open() || m_ptr->info()->is_active())
     throw internal_error("Download::hash_check(...) called on a closed or active download.");
@@ -127,11 +127,11 @@ Download::hash_check(bool tryQuick) {
   if (m_ptr->hash_checker()->is_checked())
     throw internal_error("Download::hash_check(...) called but already hash checked.");
 
-  // The bitfield still hasn't been allocated, so no resume data was
-  // given. 
   Bitfield* bitfield = m_ptr->main()->file_list()->mutable_bitfield();
 
   if (bitfield->empty()) {
+    // The bitfield still hasn't been allocated, so no resume data was
+    // given. 
     bitfield->allocate();
     bitfield->unset_all();
 
@@ -253,6 +253,11 @@ Download::down_rate() const {
   return m_ptr->info()->down_rate();
 }
 
+Rate*
+Download::mutable_down_rate() {
+  return m_ptr->info()->down_rate();
+}
+
 Rate*
 Download::up_rate() {
   return m_ptr->info()->up_rate();
@@ -263,6 +268,11 @@ Download::up_rate() const {
   return m_ptr->info()->up_rate();
 }
 
+Rate*
+Download::mutable_up_rate() {
+  return m_ptr->info()->up_rate();
+}
+
 Rate*
 Download::skip_rate() {
   return m_ptr->info()->skip_rate();
@@ -273,6 +283,11 @@ Download::skip_rate() const {
   return m_ptr->info()->skip_rate();
 }
 
+Rate*
+Download::mutable_skip_rate() {
+  return m_ptr->info()->skip_rate();
+}
+
 uint64_t
 Download::bytes_done() const {
   uint64_t a = 0;
