@@ -76,6 +76,10 @@ public:
   void                start();
   void                stop();
 
+//   static const int start_no_create = 0x1;
+
+//   void                start(int flags);
+
   // Does not check if the download has been removed.
   bool                is_valid() const { return m_ptr; }
 
@@ -105,14 +109,18 @@ public:
   const PeerList*     peer_list() const;
   const TransferList* transfer_list() const;
 
+  // Remove the old non-const versions.
   Rate*               down_rate();
   const Rate*         down_rate() const;
+  Rate*               mutable_down_rate();
 
   Rate*               up_rate();
   const Rate*         up_rate() const;
+  Rate*               mutable_up_rate();
 
   Rate*               skip_rate();
   const Rate*         skip_rate() const;
+  Rate*               mutable_skip_rate();
 
   // Bytes completed.
   uint64_t            bytes_done() const;
